@@ -11,6 +11,10 @@ func (c *Client) PingC2S(jid, server string) error {
 	if server == "" {
 		server = c.domain
 	}
+	// Reset ticker for periodic pings if configured.
+	if c.periodicPings {
+		c.periodicPingTicker.Reset(c.periodicPingPeriod)
+	}
 	_, err := fmt.Fprintf(c.stanzaWriter, "<iq from='%s' to='%s' id='%s' type='get'>"+
 		"<ping xmlns='urn:xmpp:ping'/>"+
 		"</iq>\n",
@@ -19,6 +23,10 @@ func (c *Client) PingC2S(jid, server string) error {
 }
 
 func (c *Client) PingS2S(fromServer, toServer string) error {
+	// Reset ticker for periodic pings if configured.
+	if c.periodicPings {
+		c.periodicPingTicker.Reset(c.periodicPingPeriod)
+	}
 	_, err := fmt.Fprintf(c.stanzaWriter, "<iq from='%s' to='%s' id='%s' type='get'>"+
 		"<ping xmlns='urn:xmpp:ping'/>"+
 		"</iq>\n",
@@ -27,7 +35,17 @@ func (c *Client) PingS2S(fromServer, toServer string) error {
 }
 
 func (c *Client) SendResultPing(id, toServer string) error {
+	// Reset ticker for periodic pings if configured.
+	if c.periodicPings {
+		c.periodicPingTicker.Reset(c.periodicPingPeriod)
+	}
 	_, err := fmt.Fprintf(c.stanzaWriter, "<iq type='result' to='%s' id='%s'/>\n",
 		xmlEscape(toServer), xmlEscape(id))
 	return err
 }
+
+func (c *Client) sendPeriodicPings() {
+	for range c.periodicPingTicker.C {
+		_ = c.PingC2S(c.jid, c.domain)
+	}
+}
